Command line interface
======================

.. click:: pyproject2conda.cli:app
    :prog: pyproject2conda
    :nested: full
    :commands: list, yaml, requirements, project, conda-requirements, json
